pub enum EmptyLineTag {
Br,
P,
}Expand description
The tag that should be used to represent empty Text lines.
Variants
Br
Empty Text lines consist of a single line break tag (e.g. <br>)
P
Empty Text lines consist of an empty paragraph tag (e.g. <p></p>)